Struct FredClient

pub struct FredClient { /* private fields */ }
Persistent client object used to access the FRED API

Each method for the client represents a data endpoint provided by the API and will return a data object representing the response contents.

Implementations

Source

impl FredClient

pub fn new() -> Result<FredClient, String>

Creates and initializes a new client object

The client will attempt to load an API key from the environment variable ‘FRED_API_KEY’. If this variable is undefined, the key remains empty.

If a connection cannot be made to the FRED API, it returns Err containing an error message.

use fred_rs::client::FredClient;
 
let mut client = match FredClient::new() {
    Ok(c) => c,
    Err(msg) => {
        println!("{}", msg);
        return
    },
};
pub fn with_key(&mut self, key: &str)

Sets the FRED API key for the client

Arguments
  • key - The API key generated to access FRED
use fred_rs::client::FredClient;
 
let mut client = match FredClient::new() {
    Ok(c) => c,
    Err(msg) => {
        println!("{}", msg);
        return
    },
};
 
client.with_key("abcdefghijklmnopqrstuvwxyz123456");
pub fn series( &mut self, series_id: &str, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::series

Arguments

series_id - The id for a series [Link]

pub fn series_categories( &mut self, series_id: &str, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::series::categories

Arguments

series_id - The id for a series [Link]

pub fn series_observation( &mut self, series_id: &str, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::series::observation

Arguments

series_id - The id for a series [Link]

pub fn series_release( &mut self, series_id: &str, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::series::release

Arguments

series_id - The id for a series [Link]

pub fn series_tags( &mut self, series_id: &str, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::series::tags

Arguments

series_id - The id for a series [Link]

pub fn series_updates( &mut self, builder: Option<Builder>, ) -> Result<Response, String>

pub fn series_vintagedates( &mut self, series_id: &str, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::series::vintagedates

Arguments

series_id - The id for a series [Link]

See fred_rs::series::search

Arguments

search_text - The words to match against economic data series [Link]

pub fn series_search_tags( &mut self, series_search_text: &str, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::series::search::tags

Arguments

series_search_text - The words to match against economic data series [Link]

See fred_rs::series::search::related_tags

Arguments

series_search_text - The words to match against economic data series [Link]

pub fn tags(&mut self, builder: Option<Builder>) -> Result<Response, String>

pub fn tags_series(&mut self, builder: Builder) -> Result<Response, String>

pub fn related_tags(&mut self, builder: Builder) -> Result<Response, String>

pub fn sources(&mut self, builder: Option<Builder>) -> Result<Response, String>

pub fn source( &mut self, source_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::source

Arguments

source_id - The id for a source [Link]

pub fn source_releases( &mut self, source_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::source::releases

Arguments

source_id - The id for a source [Link]

pub fn category(&mut self, category_id: usize) -> Result<Response, String>

See fred_rs::category

Arguments

category_id - The id for a category [Link]

pub fn category_children( &mut self, category_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::category::children

Arguments

category_id - The id for a category [Link]

See fred_rs::category::related

Arguments

category_id - The id for a category [Link]

pub fn category_series( &mut self, category_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::category::series

Arguments

category_id - The id for a category [Link]

pub fn category_tags( &mut self, category_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::category::tags

Arguments

category_id - The id for a category [Link]

See fred_rs::category::related_tags

Arguments

category_id - The id for a category [Link]

pub fn releases(&mut self, builder: Option<Builder>) -> Result<Response, String>

pub fn releases_dates( &mut self, builder: Option<Builder>, ) -> Result<Response, String>

pub fn release( &mut self, release_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::release

Arguments

release_id - The id for a release [Link]

pub fn release_series( &mut self, release_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::release::series

Arguments

release_id - The id for a release [Link]

pub fn release_sources( &mut self, release_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::release::sources

Arguments

release_id - The id for a release [Link]

pub fn release_tags( &mut self, release_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::release::tags

Arguments

release_id - The id for a release [Link]

See fred_rs::release::related_tags

Arguments

release_id - The id for a release [Link]

pub fn release_tables( &mut self, release_id: usize, builder: Option<Builder>, ) -> Result<Response, String>

See fred_rs::release::tables

Arguments

release_id - The id for a release [Link]