pub enum FilterVariable {
Frequency,
Units,
SeasonalAdjustment,
}Expand description
Apply result filter
This should be used in conjunction with the filter_value argument to filter results based on one (maybe more than one?) of the fields.
https://research.stlouisfed.org/docs/api/fred/release_series.html#filter_variable
Variants