pub enum AggregationMethod {
AVG,
SUM,
EOP,
}Expand description
Provides an aggregation method for frequency aggregation
This argument should be used in conjunction with the frequency argument if the default aggregation method (AVG) is not preferred.
https://research.stlouisfed.org/docs/api/fred/series_observations.html#aggregation_method
Variants
AVG
Average (default): intermediate datapoints are averaged to produce the aggregate
SUM
Sum: intermediate datapoints are summed to produce the aggregate
EOP
End of Period: The final result in the period is returned