pub struct Response {
pub realtime_start: String,
pub realtime_end: String,
pub order_by: Option<String>,
pub sort_order: Option<String>,
pub count: Option<usize>,
pub offset: Option<usize>,
pub limit: Option<usize>,
pub seriess: Vec<Series>,
}Expand description
Response data structure for the fred/series endpoint
Order_by, sort_order, count, offset and limit are used by endpoints which return a list of series. They can be ignored for the fred/series endpoint.
[https://research.stlouisfed.org/docs/api/fred/series.html] (https://research.stlouisfed.org/docs/api/fred/series.html)
Fields
realtime_start: StringThe Real Time start date for the request
realtime_end: StringThe Real Time end data for the request
order_by: Option<String>How the results are ordered
sort_order: Option<String>Results can be ascending (asc) or descending (desc)
count: Option<usize>Number of results returned
offset: Option<usize>???
limit: Option<usize>Maximum number of results to return
seriess: Vec<Series>Series matching the requested series_id
The fred/series endpoint will return a series for each time a series changed. For example Real GNP has been calculated several different ways over time so this endpoint will return a different series for each time period becasue they all fit under the same symbol: GNPCA.